@@ -16,6 +16,7 @@ from petisco.domain.errors.empty_value_object_error import EmptyValueObjectError
 from petisco.domain.errors.length_limit_string_value_object_error import (
     ExceedLengthLimitValueObjectError,
     NotReachMinimumValueObjectError,
+    NotHasSpecificLengthValueObjectError,
 )
 from petisco.domain.errors.given_name_is_not_valid_error import GivenNameIsNotValidError
 from petisco.domain.errors.unknown_error import UnknownError
@@ -42,6 +43,7 @@ from petisco.http.request_errors import (
     ConnectionRequestError,
     UnknownRequestError,
     UnauthorizedRequestError,
+    BadRequestError,
 )
 from petisco.http.response import Response
 from petisco.logger.log_message import LogMessage
@@ -87,6 +89,8 @@ from petisco.event.legacy.subscriber.infrastructure.not_implemented_event_subscr
     NotImplementedEventSubscriber,
 )
 from petisco.event.shared.domain.event_subscriber import EventSubscriber
+from petisco.webhooks.webhook.domain.secret import SecretIsNotHexError, Secret
+from petisco.webhooks.webhook.domain.signature_algorithm import SignatureAlgorithm
 from petisco.webhooks.webhook.domain.webhook import Webhook
 from petisco.webhooks.webhook.domain.webhook_id import WebhookId
 from petisco.webhooks.webhook.domain.webhook_sender import WebhookSender
@@ -153,12 +157,17 @@ classes = [
     "ConnectionRequestError",
     "UnknownRequestError",
     "UnauthorizedRequestError",
+    "BadRequestError",
     "IEventBus",
     "event_handler",
     "Webhook",
     "WebhookSender",
     "WebhookId",
     "IEventChaos",
+    "SecretIsNotHexError",
+    "NotHasSpecificLengthValueObjectError",
+    "Secret",
+    "SignatureAlgorithm",
 ]
 
 # Controllers & Use Cases
